Management commands — django-richtemplates v0.3.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-richtemplates v0.3.4 documentation »

# Management commands

This section describes available, custom management commands included with `richtemplates` application.

## `import_media` command

class `richtemplates.management.commands.import_media.` `Command`

  Copies `media` directory from django pluggable app into this project.

  If `media` directory would containt subdirectory called same as this application’s `app_label`, this subdirectory would become source directory (i.e. this would import media from excellent django-admin-tools properly).

  Source directory is put into `media` directory inside the project. If this destination directory does not exist it would be created.

  Synopsis

      1
      ./manage.py import_media [options] app [app2] [app3] ...

  Options

  `--fail-silently`

    Default: `False`

    Turning on would not raise exception if specified `app` does not have `media` directory.

  `--force`

    Default: `False`

    By default, if destination directory already exists, `CommandError` would be raised. By turning this flag on check is not made.

  `--media-root`

    Default: same as `django.settings.MEDIA_ROOT`

    This is destination directory. All source directories would be copied as subdirectories into this directory.

### Navigation

- index
- modules |
- next |
- previous |
- django-richtemplates v0.3.4 documentation »